from torch_geometric.data import InMemoryDataset
import torch
import pandas as pd

class MicrostructuralDamageDatasetV1(InMemoryDataset):
    """  
    The MicrostructuralDamage dataset from the "Materials fatigue prediction using graph neural networks on microstructure representations" paper, containing 7633 nodes (grains) with each having 100 features, and 40910 edges (adjacency of grains).

    Args:
        root (string): Root directory where the dataset is saved.
    """
    def __init__(self, root, transform=None, pre_transform=None):
        super(MicrostructuralDamageDatasetV1, self).__init__(root, transform, pre_transform)
        self.data, self.slices = torch.load(self.processed_paths[0])
        store = pd.HDFStore(self.raw_paths[0])
        damage_dataset = store["df"]
        self.damage_dataset = damage_dataset.groupby(level="grain").max()

    @property
    def raw_file_names(self):
        return ['microstructural_damage_dataset_tabular.h5']

    @property
    def processed_file_names(self):
        return ['data.pt']

    def download(self):
        pass
    
    def process(self):
        pass