# Microstructural damage data set

This data set contains information about microstructure-sensitive damage in ferritic steel (EN 1.4003) specimens. We provide both graph and tabular data sets. 
In the graph data set, each node is a grain in the material, and each edge connects adjacent grains. Annotation is provided to each of the grains mentioning if it developed damage (protrusion in this case) during a fatigue test.
The annotation is provided based on fatigue tests performed on the specimen.

## List of files
This data set contains the following files:
- MicrostructuralDamageDatasetV1/processed/data.pt
- MicrostructuralDamageDatasetV1/raw/microstructural_damage_dataset_tabular.h5
- microstructural_damage_dataset.py

The data.pt file contains tensors of the pytorch geometric graph data set saved as .pt file extension using torch.save.
The microstructural_damage_dataset_tabular.h5 file is tabular data set stored as a HDF5 data set.
The microstructural_damage_dataset.py defines the pytorch geometric InMemoryDataset that can be used to load the graph data set (https://pytorch-geometric.readthedocs.io/en/latest/modules/data.html#torch_geometric.data.InMemoryDataset).

## Example
An example to load the data set is as follows:

```python
from microstructural_damage_dataset import MicrostructuralDamageDatasetV1
dataset = MicrostructuralDamageDatasetV1("MicrostructuralDamageDatasetV1")
print()
print(f'Dataset: {dataset}:')
print('====================')
print(f'Number of graphs: {len(dataset)}')
print(f'Number of features: {dataset.num_features}')
print(f'Number of classes: {dataset.num_classes}')

data = dataset[0]  # Get the first graph object.

print()
print(data)
print('=============================================================')

# Gather some statistics about the first graph.
print(f'Number of nodes: {data.num_nodes}')
print(f'Number of edges: {data.num_edges}')
print(f'Average node degree: {data.num_edges / data.num_nodes:.2f}')
print(f'Contains isolated nodes: {data.has_isolated_nodes()}')
print(f'Contains self-loops: {data.has_self_loops()}')
print(f'Is undirected: {data.is_undirected()}')
```